import router from "@/router";
import { useUserStore } from "@/store/modules/user";
import { usePermissionStore } from "@/store/modules/permission";
import { useDictionaryStore } from "@/store/modules/dictionary";

import NProgress from "@/utils/nprogress";
import { getUserDicts } from "@/api/auth";
import { ElStep } from "element-plus";

export function setupPermission(path: string) {
  // 白名单路由
  const whiteList = [""];

  router.beforeEach(async (to, from, next) => {
    NProgress.start();
    const hasToken = localStorage.getItem("token");

    const dictStore = useDictionaryStore();
    if (
      !dictStore.dicts.value ||
      JSON.stringify(dictStore.dicts.value) === "{}"
    ) {
      const res = await getUserDicts(dictStore.types);
      if (res.data) {
        dictStore.dicts = res?.data;
      }
    }
    const userStore = useUserStore();
    if (!hasToken) {
      //自动登录
      await userStore
        .login({
          userName: "admin",
          password: "123456",
          orgId: 1,
        })
        .then(async () => {
          if (userStore.isGetAuth) {
            // 未匹配到任何路由，跳转404
            if (to.matched.length === 0) {
              from.name ? next({ name: from.name }) : next("/404");
            } else {
              next();
            }
          } else {
            const permissionStore = usePermissionStore();
            try {
              const { menus } = await userStore.getUserInfo();
              const accessRoutes = await permissionStore.generateRoutes(menus);
              accessRoutes.forEach((route) => {
                router.addRoute(route);
              });
              console.log(router, path);

              next({ path: path });
            } catch (error) {
              console.error("beforeEach error", error);
              // 移除 token 并跳转登录页
              await userStore.resetToken();

              NProgress.done();
            }
          }
        });
    } else {
      if (userStore.isGetAuth) {
        // 未匹配到任何路由，跳转404
        if (to.matched.length === 0) {
          from.name ? next({ name: from.name }) : next("/404");
        } else {
          next();
        }
      } else {
        const permissionStore = usePermissionStore();
        try {
          const { menus } = await userStore.getUserInfo();

          const accessRoutes = await permissionStore.generateRoutes(menus);

          accessRoutes.forEach((route) => {
            router.addRoute(route);
          });
          next({ path: path });
        } catch (error) {
          console.error("beforeEach error", error);
          // 移除 token 并跳转登录页
          await userStore.resetToken();
          NProgress.done();
        }
      }
    }
  });

  router.afterEach(() => {
    NProgress.done();
  });
}
